@@ -484,60 +484,60 @@ HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, H
 
 from django.utils.safestring import mark_safe
 
-class DataTransformerForm(BaseInlineFormSet):
+# class DataTransformerForm(BaseInlineFormSet):
 
-    def add_fields(self, form, index):
-        super(DataTransformerForm, self).add_fields(form, index)
-
-        if hasattr(form.instance, 'accessory') and form.instance.accessory is not None:
-            dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self.__class__,
-                                                                 fk_name='parent', form=DataTransform
-                                                                 )
-            form.nested_data_transformer_form = dataTransformerInlineFormset(
-                instance=form.instance,
-                data=form.data if form.is_bound else None,
-                files=form.files if form.is_bound else None,
-                initial=[{'parent': form.instance}]
-            )
-
-
-
-        form.nested_constants_form = DataConstantsTransformerInlineFormset(
-            instance=form.instance,
-            data=form.data if form.is_bound else None,
-            files=form.files if form.is_bound else None
-        )
-
-        form.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
-            instance=form.instance,
-            data=form.data if form.is_bound else None,
-            files=form.files if form.is_bound else None
-        )
-
-        form.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
-            instance=form.instance,
-            data=form.data if form.is_bound else None,
-            files=form.files if form.is_bound else None
-        )
-
-    def as_p(self):
-        # super(self.__class__,self).as_p()
-        forms = ' '
-        for form in self:
-            forms = ' '.join([forms,form.as_p()])
-            if hasattr(form, 'nested_data_transformer_form') and form.nested_data_transformer_form is not None:
-                forms = ' '.join([forms,form.nested_data_transformer_form.as_p()])
-            if hasattr(form, 'nested_constants_form') and form.nested_constants_form is not None:
-
-                forms = ' '.join([forms,form.nested_constants_form.as_p()])
-            if hasattr(form, 'nested_hardware_outputs_form') and form.nested_hardware_outputs_form is not None:
-
-                forms = ' '.join([forms,form.nested_hardware_outputs_form.as_p()])
-            if hasattr(form, 'nested_hardware_stats_form') and form.nested_hardware_stats_form is not None:
-
-                forms = ' '.join([forms,form.nested_hardware_stats_form.as_p()])
-
-        return mark_safe(str(self.management_form) + '\n' + forms)
+    # def add_fields(self, form, index):
+    #     super(DataTransformerForm, self).add_fields(form, index)
+    #
+        # if hasattr(form.instance, 'accessory') and form.instance.accessory is not None:
+        #     dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self.__class__,
+        #                                                          fk_name='parent', form=DataTransform
+        #                                                          )
+        #     form.nested_data_transformer_form = dataTransformerInlineFormset(
+        #         instance=form.instance,
+        #         data=form.data if form.is_bound else None,
+        #         files=form.files if form.is_bound else None,
+        #         initial=[{'parent': form.instance}]
+        #     )
+        #
+        #
+        #
+        # form.nested_constants_form = DataConstantsTransformerInlineFormset(
+        #     instance=form.instance,
+        #     data=form.data if form.is_bound else None,
+        #     files=form.files if form.is_bound else None
+        # )
+        #
+        # form.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
+        #     instance=form.instance,
+        #     data=form.data if form.is_bound else None,
+        #     files=form.files if form.is_bound else None
+        # )
+        #
+        # form.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
+        #     instance=form.instance,
+        #     data=form.data if form.is_bound else None,
+        #     files=form.files if form.is_bound else None
+        # )
+    #
+    # def as_p(self):
+    #     # super(self.__class__,self).as_p()
+    #     forms = ''
+    #     for form in self:
+    #         forms = '   '.join([forms,form.as_p()])
+    #         if hasattr(form, 'nested_data_transformer_form') and form.nested_data_transformer_form is not None:
+    #             forms = '       -'.join([forms,form.nested_data_transformer_form.as_p()])
+    #         if hasattr(form, 'nested_constants_form') and form.nested_constants_form is not None:
+    #
+    #             forms = ' '.join([forms,form.nested_constants_form.as_p()])
+    #         if hasattr(form, 'nested_hardware_outputs_form') and form.nested_hardware_outputs_form is not None:
+    #
+    #             forms = ' '.join([forms,form.nested_hardware_outputs_form.as_p()])
+    #         if hasattr(form, 'nested_hardware_stats_form') and form.nested_hardware_stats_form is not None:
+    #
+    #             forms = ' '.join([forms,form.nested_hardware_stats_form.as_p()])
+    #
+    #     return mark_safe(str(self.management_form) + '\n' + forms)
 
 
 class DataTransform(forms.ModelForm):
@@ -551,42 +551,118 @@ class DataTransform(forms.ModelForm):
     type = forms.CharField(required=True,
                            widget=forms.TextInput(attrs={'class': 'form-control'}))
 
+    def __init__(self, *args, **kwargs):
+        super(DataTransform, self).__init__(*args, **kwargs)
+        if hasattr(self.instance, 'accessory') and self.instance.accessory is not None:
+            dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
+                                                                 formset=self.__class__,
+                                                                 fk_name='parent', form=DataTransform
+                                                                 )
+            self.nested_data_transformer_form = dataTransformerInlineFormset(
+                instance=self.instance,
+                data=self.data if self.is_bound else None,
+                files=self.files if self.is_bound else None,
+                initial=[{'parent': self.instance}]
+            )
+
+        self.nested_constants_form = DataConstantsTransformerInlineFormset(
+            instance=self.instance,
+            data=self.data if self.is_bound else None,
+            files=self.files if self.is_bound else None
+        )
+
+        self.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
+            instance=self.instance,
+            data=self.data if self.is_bound else None,
+            files=self.files if self.is_bound else None
+        )
+
+        self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
+            instance=self.instance,
+            data=self.data if self.is_bound else None,
+            files=self.files if self.is_bound else None
+        )
+
+    def as_p(self):
+        # super(self.__class__,self).as_p()
+        forms = ''
+        forms = '   '.join([forms,super(self.__class__,self).as_p()])
+
+        if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
+            forms = ' '.join([forms,self.nested_constants_form.as_p()])
+        if hasattr(self, 'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
+            forms = ' '.join([forms,self.nested_hardware_outputs_form.as_p()])
+        if hasattr(self, 'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
+            forms = ' '.join([forms,self.nested_hardware_stats_form.as_p()])
+        if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
+            forms = '       -'.join([forms,self.nested_data_transformer_form.as_p()])
+        return mark_safe(forms)
+    class Meta:
+        model = DataTransformer
+        fields = ['id','accessory','parent','type']
+# DataTransformerFormset = form_factory(DataTransformer,formset=DataTransformerForm)
+
+
+class DataTransformRoot(forms.ModelForm):
+    id = forms.CharField(required=False,
+                         widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    accessory = forms.CharField(required=False,
+                                widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    type = forms.CharField(required=True,
+                           widget=forms.TextInput(attrs={'class': 'form-control'}))
+
 
 
     # def __init__(self, *args, **kwargs):
     #     super(HardwareTypeForm, self).__init__(*args, **kwargs)
     def __init__(self, *args, **kwargs):
-        super(DataTransform, self).__init__(*args, **kwargs)
-        # self.__name__ = 'DataTransform'
-        # dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
-        #                                                      fk_name='data_transformer_parent',
-        #                                                      extra=1, exclude=['updated_at', 'created_at'],
-        #                                                      form=self.__class__)
-        # self.nested_data_transformer_form = dataTransformerInlineFormset(
-        #     instance=self,
-        #     data=self.data if self.is_bound else None,
-        #     files=self.files if self.is_bound else None,
-        #     extra=1)
-        #
-        # self.nested_constants_form = DataConstantsTransformerInlineFormset(
-        #     instance=self,
-        #     data=self.data if self.is_bound else None,
-        #     files=self.files if self.is_bound else None,
-        #     extra=1)
-        #
-        # self.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
-        #     instance=self,
-        #     data=self.data if self.is_bound else None,
-        #     files=self.files if self.is_bound else None,
-        #     extra=1)
-        #
-        # self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
-        #     instance=self,
-        #     data=self.data if self.is_bound else None,
-        #     files=self.files if self.is_bound else None,
-        #     extra=1)
+        super(DataTransformRoot, self).__init__(*args, **kwargs)
+        if hasattr(self.instance, 'accessory') and self.instance.accessory is not None:
+            dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
+                                                                 formset=self.__class__,
+                                                                 fk_name='parent', form=DataTransform
+                                                                 )
+            self.nested_data_transformer_form = dataTransformerInlineFormset(
+                instance=self.instance,
+                data=self.data if self.is_bound else None,
+                files=self.files if self.is_bound else None,
+                initial=[{'parent': self.instance}]
+            )
+
+        self.nested_constants_form = DataConstantsTransformerInlineFormset(
+            instance=self.instance,
+            data=self.data if self.is_bound else None,
+            files=self.files if self.is_bound else None
+        )
+
+        self.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
+            instance=self.instance,
+            data=self.data if self.is_bound else None,
+            files=self.files if self.is_bound else None
+        )
+
+        self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
+            instance=self.instance,
+            data=self.data if self.is_bound else None,
+            files=self.files if self.is_bound else None
+        )
+
+    def as_p(self):
+        # super(self.__class__,self).as_p()
+        forms = ''
+        forms = '   '.join([forms,super(self.__class__,self).as_p()])
+
+        if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
+            forms = ' '.join([forms,self.nested_constants_form.as_p()])
+        if hasattr(self, 'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
+            forms = ' '.join([forms,self.nested_hardware_outputs_form.as_p()])
+        if hasattr(self, 'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
+            forms = ' '.join([forms,self.nested_hardware_stats_form.as_p()])
+        if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
+            forms = '       -'.join([forms,self.nested_data_transformer_form.as_p()])
+        return mark_safe(forms)
 
     class Meta:
         model = DataTransformer
-        fields = ['id','accessory','parent','type']
+        fields = ['id','accessory','type']
 # DataTransformerFormset = form_factory(DataTransformer,formset=DataTransformerForm)
