@@ -363,7 +363,7 @@ class HardwareViewSet(viewsets.ModelViewSet):
             return HttpResponse(render(request, 'hardwares.html'))
 
 
-from data.forms.forms import DataTransformerForm, DataTransform, DataTransformRoot
+from data.forms.forms import  DataTransform, DataTransformRoot
 from data.models.models import DataTransformer
 
 
@@ -433,7 +433,7 @@ class AccessoryViewSet(viewsets.ModelViewSet):
     def postDataTransformer(request):
         # request should be ajax and method should be POST.
         if request.is_ajax and request.method == "POST":
-            form = DataTransformerForm(request.POST)
+            form = DataTransformRoot(request.POST)
             if form.is_valid():
                 instance = form.save()
                 print(str(instance))
